#!/bin/bash


# Check if script is being run as root
if [[ $EUID -ne 0 ]]; then
    echo "This script must be run as root (sudo)" 
    exit 1
fi

INSTALL_DIRECTORY="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"

source $INSTALL_DIRECTORY/installer-variables-linux.conf 

echo You are about to uninstall Vacation Booking.
echo Please make sure that all variables in conf file are accurate.
echo
echo WARNING: WAS Profile, Apache Tomcat Install, Apache ActiveMQ, MQ Queue
echo manager and the DB2 instance are deleted.
echo
echo NOTE: If the previous configuration used for install or installed products
echo have changed this uninstall may generate errors. Some can safely be ignored
echo e.g. attempt to remove the VBEXRATE database when it does not exist.

echo 

choice=''
while [[ $choice != 'Y' && $choice != 'N' ]];
do
    echo -n 'Are you sure you want to continue?[Y/n] ' 
    read choice
    choice=`echo $choice | tr [:lower:] [:upper:]`
done

if [[ $choice == 'N' ]];
then
    exit
fi


# remove uninstall logs directory, if it exists
rm -rf $INSTALL_DIRECTORY/uninstall-logs

mkdir $INSTALL_DIRECTORY/uninstall-logs


echo Uninstalling Vacation Booking from  WAS ..
# Uninstall WAS
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-WAS.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-WAS.log

echo Uninstalling Vacation Booking from Websphere MQ
# Uninstall Websphere MQ
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-queues.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-queues.log

echo Uninstalling Vacation Booking from DB2
# Uninstall DB2
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-database.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-database.log


echo Uninstalling Vacation Booking from Tomcat
# Uninstall Tomcat
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-tomcat.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-tomcat.log

echo Uninstalling Vacation Booking from ActiveMQ
# Uninstall ActiveMQ
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-activemq.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-activemq.log

echo Uninstalling Vacation Booking scripts
# Remove scripts
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-scripts.sh &> $INSTALL_DIRECTORY/uninstall-logs/uninstall-scripts.log

echo Uninstalling standalone apps
# Remove standalone apps
$INSTALL_DIRECTORY/vbooking/scripts/install/Uninstall-VBooking-standalone.sh &>$INSTALL_DIRECTORY/uninstall-logs/uninstall-standalone.log

echo Vacation Booking is uninstalled.
echo
echo Please check the logs located in uninstall-logs folder to see if installation was succesful.










