CREATE PROCEDURE doSeatCheck(
		IN flightNumber VARCHAR(200),
		IN weekNumber VARCHAR(200), 
		OUT clearToBookStatus BOOLEAN,
		OUT confirmationCode TIMESTAMP,
		OUT warning VARCHAR(200))
	LANGUAGE SQL
BEGIN
	-- Simply stored procedure that counts the number of people booked on the flight for the week requested
	-- and compares it to the number of seats advertised on the flight.
	-- If the number of seats available is less than 1, then the booking fails
	DECLARE totalReservations INTEGER;
	DECLARE totalSeats INTEGER;
	SET totalReservations = (SELECT COUNT(RESERVATION_NUMBER) FROM RESERVATION 
									WHERE FLIGHT_NUMBER = flightNumber AND WEEK_NUMBER = weekNumber);
	SET totalSeats = (SELECT TOTAL_SEATS FROM FLIGHTS WHERE FLIGHT_NO = flightNumber);
	
	-- If flight is not in system then assume it's unlimited
	IF (totalSeats IS NULL) THEN
		SET totalSeats = 0;
	END IF;
	
	IF (totalSeats = 0) THEN
		-- Always allow booking
		SET clearToBookStatus = TRUE;
		SET confirmationCode = (SELECT CURRENT_TIMESTAMP FROM sysibm.sysdummy1);
		SET warning = '';
	ELSEIF (totalSeats > totalReservations) THEN
		SET clearToBookStatus = TRUE;
		SET confirmationCode = (SELECT CURRENT_TIMESTAMP FROM sysibm.sysdummy1);
		SET warning = '';
	ELSE 
		SET clearToBookStatus = FALSE;
		SET confirmationCode = (SELECT CURRENT_TIMESTAMP FROM sysibm.sysdummy1);
		SET warning = 'Booking failed. There are no seats available on this flight for the requested week.';
	END IF;
END@
