@echo off
rem
rem Setup activemq and configure it
rem

echo Installing and configuring ActiveMQ....

SET SCRIPT_PATH=%~dp0
SET CURRENT_PATH=%cd%

cd "%SCRIPT_PATH%"

rem Should a new activemq folder be installed?
call Utils.bat readConfYN USE_PRE_INSTALLED_ACTIVEMQ N
call Utils.bat readConf ACTIVEMQ_PATH
call Utils.bat readConf ACTIVEMQ_ZIP
call Utils.bat readConf ACTIVEMQ_ZIP_SUB_FOLDER
SET activemqFolder=%ACTIVEMQ_PATH%
if %USE_PRE_INSTALLED_ACTIVEMQ% == N (
	echo Installing ActiveMQ to %ACTIVEMQ_PATH%
	cscript //NoLogo Utils.vbs UnzipIt "%CURRENT_PATH%\%ACTIVEMQ_ZIP%" %ACTIVEMQ_PATH%
)
REM redirect activemqFolder to sub folder location?
IF EXIST %ACTIVEMQ_PATH%\%ACTIVEMQ_ZIP_SUB_FOLDER% (
	set activemqFolder=%ACTIVEMQ_PATH%\%ACTIVEMQ_ZIP_SUB_FOLDER%
)

if Not Exist "%activemqFolder%" (
	echo Unable to proceed without valid ActiveMQ installation.
	exit /b 1
)

echo Updating ActiveMQ configuration file
call Utils.bat readConf TOMCAT_PATH
call Utils.bat readConf TOMCAT_ZIP_SUB_FOLDER
set tcFolder=%TOMCAT_PATH%
IF EXIST %TOMCAT_PATH%\%TOMCAT_ZIP_SUB_FOLDER% (
	set tcFolder=%TOMCAT_PATH%\%TOMCAT_ZIP_SUB_FOLDER%
)
REM ActiveMQ changed the log4j log query classes in version 5.11.0
REM Check which version of the hotels service ActiveMQ config we need to
REM copy across
cscript //NoLogo checkforactivemqversion.vbs "%activemqFolder%" 5.11.0
SET activeMQVersionCheckResult=%ErrorLevel%
if %activeMQVersionCheckResult% LSS 0 (
	if %activeMQVersionCheckResult% EQU -2 (
		echo "WARNING: Could not determine the version of the ActiveMQ installation. Assuming 5.9.0 - manual intervention may be required."
	)
	set activemqConfigFilePath=%tcFolder%\webapps\hotelsWS\configurationFiles\activemq.xml
) else (
	set activemqConfigFilePath=%tcFolder%\webapps\hotelsWS\configurationFiles\activemq-5.11.0.xml
)
copy /Y /V "%activemqConfigFilePath%" "%activemqFolder%"\conf\activemq.xml

echo Moving ActiveMQ jars to tomcat
copy /y %activemqFolder%\activemq-all-*.jar %tcFolder%\webapps\vbooking-home\WEB-INF\lib
copy /y %activemqFolder%\activemq-all-*.jar %tcFolder%\webapps\hotelsWS\WEB-INF\lib


echo Updating hotel booking service properties file
call Utils.bat readConf HOTEL_PAYMENT_BACKEND_TECHNOLOGY
call Utils.bat readConf ACTIVEMQ_MESSAGE_TYPE
call Utils.bat readConf ACTIVEMQ_BROKER_URL
set tcHSFolder=%tcFolder%\webapps\hotelsWS\WEB-INF\classes\com\vbooking\booking\hotel
cscript //NoLogo Utils.vbs ReplaceToken "%tcHSFolder%"\hotelWS.properties HOTEL_PAYMENT_BACKEND_TECHNOLOGY= HOTEL_PAYMENT_BACKEND_TECHNOLOGY=%HOTEL_PAYMENT_BACKEND_TECHNOLOGY%
cscript //NoLogo Utils.vbs ReplaceToken "%tcHSFolder%"\hotelWS.properties ACTIVEMQ_MESSAGE_TYPE= ACTIVEMQ_MESSAGE_TYPE=%ACTIVEMQ_MESSAGE_TYPE%
cscript //NoLogo Utils.vbs ReplaceToken "%tcHSFolder%"\hotelWS.properties ACTIVEMQ_BROKER_URL= ACTIVEMQ_BROKER_URL=%ACTIVEMQ_BROKER_URL%

echo Starting ActiveMQ
echo "ActiveMQ needs to be started manually through 'activemq' script installed at %activemqFolder%"
cd /d "%activemqFolder%"\bin
REM from ActiveMQ 5.10.0 onwards, they changed the batch file to not automatically issue
REM the 'start' command in order to start the broker. Must explicitly provide the argument
REM for 5.10.0 onwards.
cscript //NoLogo "%SCRIPT_PATH%/checkforactivemqversion.vbs" "%activemqFolder%" 5.10.0
SET activeMQVersionCheckResult=%ErrorLevel%
if %activeMQVersionCheckResult% LSS 0 (
	call start activemq.bat
) else (
	call start activemq.bat start
)
cd /d "%SCRIPT_PATH%"

echo ActiveMQ installed and configured!
