#!/bin/bash
#
# Setup activemq and configure it
#

echo "Installing and configuring ActiveMQ...."
THIS_SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${THIS_SCRIPT_PATH}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

echo "Unzipping ActiveMQ"
mkdir -p $ACTIVEMQ_PATH
mkdir /tmp/activemq
tar -zxvf $SCRIPT_ROOT_PATH/$ACTIVEMQ_ZIP -C /tmp/activemq
mv /tmp/activemq/${ACTIVEMQ_ZIP%-bin.tar.gz}/* $ACTIVEMQ_PATH
rmdir /tmp/activemq/${ACTIVEMQ_ZIP%-bin.tar.gz}
rmdir /tmp/activemq

echo "Moving ActiveMQ jars to tomcat"
cp $ACTIVEMQ_PATH/activemq-all-*.jar $TOMCAT_PATH/webapps/vbooking-home/WEB-INF/lib
cp $ACTIVEMQ_PATH/activemq-all-*.jar $TOMCAT_PATH/webapps/hotelsWS/WEB-INF/lib

echo "Updating ActiveMQ configuration file"
ACTIVEMQ_CONFIG_FILE=activemq-5.11.0.xml
# ActiveMQ changed the log4j log query classes in version 5.11.0
# Check which version of the hotels service ActiveMQ config we need to
# copy across
ACTIVEMQ_VERSION_CHECK_RESULT=$($THIS_SCRIPT_PATH/checkforactivemqversion.sh $ACTIVEMQ_PATH 5.11.0)
if [ $ACTIVEMQ_VERSION_CHECK_RESULT -lt 0 ]; then
        if [ $ACTIVEMQ_VERSION_CHECK_RESULT -eq -2 ]; then
                echo "WARNING: Could not determine the version of the ActiveMQ installation. Assuming 5.9.0 - manual intervention may be required."
        fi
        ACTIVEMQ_CONFIG=activemq.xml
fi
cp -rf $TOMCAT_PATH/webapps/hotelsWS/configurationFiles/$ACTIVEMQ_CONFIG_FILE $ACTIVEMQ_PATH/conf/activemq.xml

echo "Updating hotel booking service properties file"
HOTELWS_PROPERTIES_FILE_PATH=$TOMCAT_PATH/webapps/hotelsWS/WEB-INF/classes/com/vbooking/booking/hotel/hotelWS.properties
sed -i.bak s@HOTEL_PAYMENT_BACKEND_TECHNOLOGY=.*@HOTEL_PAYMENT_BACKEND_TECHNOLOGY=$HOTEL_PAYMENT_BACKEND_TECHNOLOGY@g $HOTELWS_PROPERTIES_FILE_PATH
sed -i.bak s@ACTIVEMQ_MESSAGE_TYPE=.*@ACTIVEMQ_MESSAGE_TYPE=$ACTIVEMQ_MESSAGE_TYPE@g $HOTELWS_PROPERTIES_FILE_PATH
sed -i.bak s@ACTIVEMQ_BROKER_URL=.*@ACTIVEMQ_BROKER_URL=$ACTIVEMQ_BROKER_URL@g $HOTELWS_PROPERTIES_FILE_PATH

echo "Adding ActiveMQ user and group"
if ! id -g $USERGROUP_ACTIVEMQ >/dev/null 2>&1; then
	groupadd $USERGROUP_ACTIVEMQ
fi
if ! id -u $USERNAME_ACTIVEMQ >/dev/null 2>&1; then
	useradd -g $USERGROUP_ACTIVEMQ -M -s /sbin/nologin -d $ACTIVEMQ_PATH $USERNAME_ACTIVEMQ
fi
chown -R $USERNAME_ACTIVEMQ:$USERGROUP_ACTIVEMQ $ACTIVEMQ_PATH
usermod -a -G $USERGROUP_ACTIVEMQ $USER

echo "Setting up service vbactivemq"
sed -i.bak s@^INSTALLPATH=.*@INSTALLPATH=$ACTIVEMQ_PATH/bin@g $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbactivemq
chmod +x $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbactivemq
cp $SCRIPT_ROOT_PATH/vbooking/scripts/services/vbactivemq /etc/init.d/
chkconfig --add vbactivemq
chkconfig vbactivemq on

echo "Starting ActiveMQ"
service vbactivemq start

echo "ActiveMQ installed and configured!"
