#!/bin/bash
#
#
# Setup the VBooking database
#
echo "Configuring DB2...."
THIS_SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${THIS_SCRIPT_PATH}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

# Create the DB2 instance user and the VBooking user
echo "Creating users"
if ! id -g $USERGROUP_DB2 >/dev/null 2>&1; then
	groupadd $USERGROUP_DB2
fi

if ! id -u $USERNAME_DB2_INSTANCE >/dev/null 2>&1; then
	useradd -g $USERGROUP_DB2 -m -d /home/$USERNAME_DB2_INSTANCE $USERNAME_DB2_INSTANCE 
	echo $USERNAME_DB2_INSTANCE:$PASSWORD_DB2_INSTANCE | chpasswd
fi

if ! id -u $USERNAME_DB2_VBOOKING >/dev/null 2>&1; then
	useradd -g $USERGROUP_DB2 -m -d /home/$USERNAME_DB2_VBOOKING $USERNAME_DB2_VBOOKING
	echo $USERNAME_DB2_VBOOKING:$PASSWORD_DB2_VBOOKING | chpasswd
fi

echo "Allowing the end user access to DB2"
usermod -a -G $USERGROUP_DB2 $USER
cat >> /home/$USER/.bashrc <<END

if [ -f /home/db2inst1/sqllib/db2profile ]; then
. /home/db2inst1/sqllib/db2profile
fi

END

# Create the DB2 fenced user - currently hardcoded
if ! id -g db2fadm1 >/dev/null 2>&1; then
	groupadd db2fadm1
fi
if ! id -u db2fenc1 >/dev/null 2>&1; then
	useradd -g db2fadm1 -m -d /home/db2fenc1 db2fenc1
fi

#Find the DB2 install location
A=$(/usr/local/bin/db2ls -c | cut -d : -f 1)
DB2_PATH=${A:6}

echo "Creating DB instance"
$DB2_PATH/instance/db2icrt -u db2fenc1 $USERNAME_DB2_INSTANCE

cat >>/etc/services <<END
db2c_db2inst1 $PORT_DB2_INSTANCE/tcp # DB2 connection service port

END

echo "Allow access to sql files"
cp $THIS_SCRIPT_PATH/*.sql /home/$USERNAME_DB2_INSTANCE/
chown $USERNAME_DB2_INSTANCE:$USERGROUP_DB2 /home/$USERNAME_DB2_INSTANCE/*.sql

echo "Creating the VBOOKING database and tables"
su - $USERNAME_DB2_INSTANCE <<-END
	db2 update database manager configuration using svcename db2c_db2inst1
	db2set DB2COMM=tcpip
	db2set DB2AUTOSTART=YES 
	db2start
	db2 create database VBOOKING
	db2 connect to VBOOKING user $USERNAME_DB2_VBOOKING using $PASSWORD_DB2_VBOOKING
	db2 CREATE SCHEMA $SCHEMA_DB2_VBOOKING AUTHORIZATION $USERNAME_DB2_VBOOKING
	db2 -tvf DB2_createReservationsTable.sql
	db2 -tvf DB2_createFlightsTable.sql
	db2 -tvf DB2_createFrequentFlyerTable.sql
	db2 -td@ -f DB2_createFlyCheckSproc.sql
	db2 -td@ -f DB2_createSeatCheckSproc.sql
	db2 disconnect VBOOKING
	
	db2 create database VBEXRATE
	db2 connect to VBEXRATE user $USERNAME_DB2_VBOOKING using $PASSWORD_DB2_VBOOKING
	db2 CREATE SCHEMA $SCHEMA_DB2_VBOOKING AUTHORIZATION $USERNAME_DB2_VBOOKING
	db2 -tvf DB2_createCurrencyTable.sql
	db2 disconnect VBEXRATE
END

echo "Cleanup SQL files"
rm -f /home/$USERNAME_DB2_VBOOKING/DB2_*.sql



echo "DB2 Configured!"

