#!/bin/bash
#
#
# Setup a queue manager, channel, and queues for VBooking
#
echo "Configuring WebSphere MQ..."
THIS_SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${THIS_SCRIPT_PATH}" )" && pwd )"
TEMP_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
SCRIPT_ROOT_PATH="$( cd "$( dirname "${TEMP_PATH}" )" && pwd )"
source $SCRIPT_ROOT_PATH/installer-variables-linux.conf

echo "Creating Queue Manager, channel and queues"
su - mqm <<END_SCRIPT

$PATH_MQ_BINARY/crtmqm -q -u SYSTEM.DEAD.LETTER.QUEUE $NAME_QUEUE_MANAGER
$PATH_MQ_BINARY/strmqm
$PATH_MQ_BINARY/runmqsc <<-END_MQSC
	ALTER QMGR CHLAUTH(DISABLED)
	DEFINE LISTENER('$NAME_QUEUE_MANAGER') TRPTYPE(TCP) PORT($PORT_QUEUE_MANAGER) CONTROL(QMGR)
	START LISTENER('$NAME_QUEUE_MANAGER')
	DEFINE CHANNEL('$CHANNEL_QUEUE_WEBAPP') CHLTYPE(SVRCONN) MCAUSER('$MQ_ADMIN_USER') TRPTYPE(TCP) LIKE(SYSTEM.DEF.SVRCONN)
	DEFINE QLOCAL('vbooking.booking') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.booking.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.booking.ff.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.reservations') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.reservations.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.checkin') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.checkin.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.global') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.global.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.multinational') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.multinational.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.worldwide') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.payment.worldwide.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.test') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.passengers') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.passengers.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.prices') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.prices.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.reservations') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('vbooking.lists.reservations.reply') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	DEFINE QLOCAL('queue.orders') LIKE(SYSTEM.DEFAULT.LOCAL.QUEUE)
	ALTER AUTHINFO(SYSTEM.DEFAULT.AUTHINFO.IDPWOS) AUTHTYPE(IDPWOS) CHCKCLNT(NONE)
	REFRESH SECURITY TYPE(CONNAUTH)
	END
END_MQSC

$PATH_MQ_BINARY/endmqm -i QM_vbooking
$PATH_MQ_BINARY/endmqlsr -m QM_vbooking & 

END_SCRIPT

echo "Adding main user to WebSphere MQ admin group"
usermod -a -G $MQ_ADMIN_GROUP $USER

echo "Creating MQ service"
chmod +x $SCRIPT_ROOT_PATH/vbooking/scripts/services/qm_vbooking
cp $SCRIPT_ROOT_PATH/vbooking/scripts/services/qm_vbooking /etc/init.d/
chkconfig --add qm_vbooking
chkconfig qm_vbooking on 
service qm_vbooking start

echo "Note: If you are running a Websphere MQ version lower than 8.0 then you might see that 2 commands have syntax errors. This is working as intended."
echo "WebSphere MQ configured!"
