#!/bin/bash
# Asks an ActiveMQ installation what its version is and compares the value
# to a target version
# IN:   Full path to root Active MQ installation e.g. /opt/activemq
# IN:   The target version to query e.g. 5.9.0
#
# OUT:  This script will output (echo) the following values:
#		-1 if the target version is less (older) than the installed version
#       0 if the versions match
#       1 if the target version is greater (newer) than the installed version
#       -2 if the version could not be determined
ACTIVEMQ_INSTALL_LOC=$1
TARGET_VERSION=$2
ACTIVEMQ_VER=$("$ACTIVEMQ_INSTALL_LOC/bin/activemq" | perl -ne 'm/ActiveMQ (\d+\.\d+(\.\d+)?)/; print "$1" ')
if [ -z $ACTIVEMQ_VER ]; then
        echo -2
        exit
fi

TARGET_VERSION_PARTS=()
ACTUAL_VERSION_PARTS=()

IFS='.' read -ra TARGET_VERSION_PARTS <<< $TARGET_VERSION
IFS='.' read -ra ACTUAL_VERSION_PARTS <<< $ACTIVEMQ_VER

MIN_PARTS=
if [ ${#TARGET_VERSION_PARTS[@]} -lt ${#ACTUAL_VERSION_PARTS[@]} ]; then
        MIN_PARTS=${#TARGET_VERSION_PARTS[@]}
else
        MIN_PARTS=${#ACTUAL_VERSION_PARTS[@]}
fi

PART=0
while [[ $PART -lt $MIN_PARTS ]]
do
        if [ ${ACTUAL_VERSION_PARTS[$PART]} -lt ${TARGET_VERSION_PARTS[$PART]} ]; then
                echo -1
                exit
        elif [ ${ACTUAL_VERSION_PARTS[$PART]} -gt ${TARGET_VERSION_PARTS[$PART]} ]; then
                echo 1
                exit
        fi
        ((PART = PART + 1))
done

if [ ${#ACTUAL_VERSION_PARTS[@]} -gt ${#TARGET_VERSION_PARTS[@]} ]; then
        echo 1
elif [ ${#ACTUAL_VERSION_PARTS[@]} -lt  ${#TARGET_VERSION_PARTS[@]} ]; then
        echo -1
fi
echo 0